# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["OAuthGrantListResponse", "Data", "Meta"]


class Data(BaseModel):
    id: str
    """Unique identifier for the OAuth grant"""

    client_id: str
    """OAuth client identifier"""

    created_at: datetime
    """Timestamp when the grant was created"""

    record_type: Literal["oauth_grant"]
    """Record type identifier"""

    scopes: List[str]
    """List of granted OAuth scopes"""

    last_used_at: Optional[datetime] = None
    """Timestamp when the grant was last used"""


class Meta(BaseModel):
    page_number: Optional[int] = None
    """Current page number"""

    page_size: Optional[int] = None
    """Number of items per page"""

    total_pages: Optional[int] = None
    """Total number of pages"""

    total_results: Optional[int] = None
    """Total number of results"""


class OAuthGrantListResponse(BaseModel):
    data: Optional[List[Data]] = None

    meta: Optional[Meta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types.ai.conversations import (
    InsightTemplateGroupDetail,
    InsightGroupRetrieveInsightGroupsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestInsightGroups:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        insight_group = client.ai.conversations.insight_groups.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.ai.conversations.insight_groups.with_raw_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        insight_group = response.parse()
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.ai.conversations.insight_groups.with_streaming_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            insight_group = response.parse()
            assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group_id` but received ''"):
            client.ai.conversations.insight_groups.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Telnyx) -> None:
        insight_group = client.ai.conversations.insight_groups.update(
            group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Telnyx) -> None:
        insight_group = client.ai.conversations.insight_groups.update(
            group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            description="description",
            name="name",
            webhook="webhook",
        )
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Telnyx) -> None:
        response = client.ai.conversations.insight_groups.with_raw_response.update(
            group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        insight_group = response.parse()
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Telnyx) -> None:
        with client.ai.conversations.insight_groups.with_streaming_response.update(
            group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            insight_group = response.parse()
            assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group_id` but received ''"):
            client.ai.conversations.insight_groups.with_raw_response.update(
                group_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Telnyx) -> None:
        insight_group = client.ai.conversations.insight_groups.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(object, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Telnyx) -> None:
        response = client.ai.conversations.insight_groups.with_raw_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        insight_group = response.parse()
        assert_matches_type(object, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Telnyx) -> None:
        with client.ai.conversations.insight_groups.with_streaming_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            insight_group = response.parse()
            assert_matches_type(object, insight_group, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group_id` but received ''"):
            client.ai.conversations.insight_groups.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_insight_groups(self, client: Telnyx) -> None:
        insight_group = client.ai.conversations.insight_groups.insight_groups(
            name="name",
        )
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_insight_groups_with_all_params(self, client: Telnyx) -> None:
        insight_group = client.ai.conversations.insight_groups.insight_groups(
            name="name",
            description="description",
            webhook="webhook",
        )
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_insight_groups(self, client: Telnyx) -> None:
        response = client.ai.conversations.insight_groups.with_raw_response.insight_groups(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        insight_group = response.parse()
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_insight_groups(self, client: Telnyx) -> None:
        with client.ai.conversations.insight_groups.with_streaming_response.insight_groups(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            insight_group = response.parse()
            assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_insight_groups(self, client: Telnyx) -> None:
        insight_group = client.ai.conversations.insight_groups.retrieve_insight_groups()
        assert_matches_type(InsightGroupRetrieveInsightGroupsResponse, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_insight_groups_with_all_params(self, client: Telnyx) -> None:
        insight_group = client.ai.conversations.insight_groups.retrieve_insight_groups(
            page={
                "number": 1,
                "size": 1,
            },
        )
        assert_matches_type(InsightGroupRetrieveInsightGroupsResponse, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve_insight_groups(self, client: Telnyx) -> None:
        response = client.ai.conversations.insight_groups.with_raw_response.retrieve_insight_groups()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        insight_group = response.parse()
        assert_matches_type(InsightGroupRetrieveInsightGroupsResponse, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_insight_groups(self, client: Telnyx) -> None:
        with client.ai.conversations.insight_groups.with_streaming_response.retrieve_insight_groups() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            insight_group = response.parse()
            assert_matches_type(InsightGroupRetrieveInsightGroupsResponse, insight_group, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncInsightGroups:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        insight_group = await async_client.ai.conversations.insight_groups.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.conversations.insight_groups.with_raw_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        insight_group = await response.parse()
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.conversations.insight_groups.with_streaming_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            insight_group = await response.parse()
            assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group_id` but received ''"):
            await async_client.ai.conversations.insight_groups.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncTelnyx) -> None:
        insight_group = await async_client.ai.conversations.insight_groups.update(
            group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncTelnyx) -> None:
        insight_group = await async_client.ai.conversations.insight_groups.update(
            group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            description="description",
            name="name",
            webhook="webhook",
        )
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.conversations.insight_groups.with_raw_response.update(
            group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        insight_group = await response.parse()
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.conversations.insight_groups.with_streaming_response.update(
            group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            insight_group = await response.parse()
            assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group_id` but received ''"):
            await async_client.ai.conversations.insight_groups.with_raw_response.update(
                group_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncTelnyx) -> None:
        insight_group = await async_client.ai.conversations.insight_groups.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(object, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.conversations.insight_groups.with_raw_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        insight_group = await response.parse()
        assert_matches_type(object, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.conversations.insight_groups.with_streaming_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            insight_group = await response.parse()
            assert_matches_type(object, insight_group, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group_id` but received ''"):
            await async_client.ai.conversations.insight_groups.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_insight_groups(self, async_client: AsyncTelnyx) -> None:
        insight_group = await async_client.ai.conversations.insight_groups.insight_groups(
            name="name",
        )
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_insight_groups_with_all_params(self, async_client: AsyncTelnyx) -> None:
        insight_group = await async_client.ai.conversations.insight_groups.insight_groups(
            name="name",
            description="description",
            webhook="webhook",
        )
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_insight_groups(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.conversations.insight_groups.with_raw_response.insight_groups(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        insight_group = await response.parse()
        assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_insight_groups(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.conversations.insight_groups.with_streaming_response.insight_groups(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            insight_group = await response.parse()
            assert_matches_type(InsightTemplateGroupDetail, insight_group, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_insight_groups(self, async_client: AsyncTelnyx) -> None:
        insight_group = await async_client.ai.conversations.insight_groups.retrieve_insight_groups()
        assert_matches_type(InsightGroupRetrieveInsightGroupsResponse, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_insight_groups_with_all_params(self, async_client: AsyncTelnyx) -> None:
        insight_group = await async_client.ai.conversations.insight_groups.retrieve_insight_groups(
            page={
                "number": 1,
                "size": 1,
            },
        )
        assert_matches_type(InsightGroupRetrieveInsightGroupsResponse, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_insight_groups(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.conversations.insight_groups.with_raw_response.retrieve_insight_groups()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        insight_group = await response.parse()
        assert_matches_type(InsightGroupRetrieveInsightGroupsResponse, insight_group, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_insight_groups(self, async_client: AsyncTelnyx) -> None:
        async with (
            async_client.ai.conversations.insight_groups.with_streaming_response.retrieve_insight_groups()
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            insight_group = await response.parse()
            assert_matches_type(InsightGroupRetrieveInsightGroupsResponse, insight_group, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from ....._models import BaseModel

__all__ = ["MessagingCreateResponse", "Data", "DataFilter"]


class DataFilter(BaseModel):
    billing_group: Optional[str] = None
    """Billing group UUID to filter by"""

    cld: Optional[str] = None
    """Called line identification (destination number)"""

    cld_filter: Optional[Literal["contains", "starts_with", "ends_with"]] = None
    """Filter type for CLD matching"""

    cli: Optional[str] = None
    """Calling line identification (caller ID)"""

    cli_filter: Optional[Literal["contains", "starts_with", "ends_with"]] = None
    """Filter type for CLI matching"""

    filter_type: Optional[Literal["and", "or"]] = None
    """Logical operator for combining filters"""

    tags_list: Optional[str] = None
    """Tag name to filter by"""


class Data(BaseModel):
    id: Optional[str] = None
    """Identifies the resource"""

    connections: Optional[List[int]] = None

    created_at: Optional[datetime] = None

    directions: Optional[List[Literal["INBOUND", "OUTBOUND"]]] = None

    end_date: Optional[datetime] = None

    filters: Optional[List[DataFilter]] = None

    profiles: Optional[List[str]] = None
    """List of messaging profile IDs"""

    record_type: Optional[str] = None

    record_types: Optional[List[Literal["INCOMPLETE", "COMPLETED", "ERRORS"]]] = None

    report_name: Optional[str] = None

    report_url: Optional[str] = None

    start_date: Optional[datetime] = None

    status: Optional[Literal["PENDING", "COMPLETE", "FAILED", "EXPIRED"]] = None

    updated_at: Optional[datetime] = None


class MessagingCreateResponse(BaseModel):
    data: Optional[Data] = None
